import { HttpRequest } from "ziron-ws";
import { HttpResponse as HttpResponse } from "./EnhanceHttpResponse";
/**
 * @description
 * Simple helper class to serve static files.
 */
export default class StaticFilesRouter {
    private readonly files;
    /**
     * @description
     * Serves a static file.
     * @example
     * file("dist/style.css","/myStyles/styles.css")
     * @param pattern
     * @param file
     * @param override
     */
    file(file: string, pattern?: string, override?: boolean): void;
    /**
     * @description
     * Serves a folder recursive.
     * @example
     * folder("dist/assets","someAssets")
     * @param folder
     * @param urlPath
     * @param options
     */
    folder(folder: string, urlPath?: string, options?: {
        filter?: (file: string) => boolean;
        linkIndex?: boolean;
        override?: boolean;
    }): void;
    /**
     * @description
     * Handles the incoming request.
     * Returns false when the response cannot be handled or a
     * truthy value when the response can be handled.
     * The truthy value is either a promise object
     * (that resolves when the file writing has been finished) or
     * a true bool value when a redirect response has been sent.
     * @param req
     * @param res
     */
    handle(req: HttpRequest, res: HttpResponse): boolean | Promise<void>;
}
